import {API, ActionType} from 'constants/content'
import _has from 'lodash.has'


var id_i = 0;



/**
 * Method for fetching content from api
 * @param path
 * @param send
 * @returns {{types: *[], promise: *, global: boolean}}
 */
export const fetch_content = (path, send) => {
    return {
        types: [ActionType.FETCH_CONTENT, ActionType.FETCH_CONTENT_COMPLETED, ActionType.FETCH_CONTENT_FAILED],
        promise: Request.get(path, send),
        global: true
    }
};


/**
 * Update content in component.
 * @param path
 * @param send
 * @param id
 * @returns {{types: *[], promise: *, params: {id: *}}}
 */
export const refresh_content = (path, send = {}, id) => {
    if (typeof id === 'undefined') throw new Error('argument id is required');

    return {
        types: [ActionType.REFRESH_CONTENT, ActionType.REFRESH_CONTENT_COMPLETED, ActionType.REFRESH_CONTENT_FAILED],
        promise: Request.get(path, send),
        params: {
            id
        }
    }
};

/**
 * Push data to api
 * @param data
 * @param key
 * @param to
 * @param destination
 * @param redirect_to
 * @returns {{types: *[], promise: *, params: {key: *, destination: *}, redirectTo}}
 */
export const push_form = ({data, key, to = '', destination, redirect_to = null}) => {
    if (typeof data === 'undefined') throw new Error('pushing data from form is not exists');

    return {
        types: [ActionType.PUSH_FORM, ActionType.PUSH_FORM_COMPLETED, ActionType.PUSH_FORM_FAILED],
        promise: Request.easy('POST', to).send(data).on('progress', e => {
            console.log(`Percentage done: ${e.percent}`);
        }),
        params: {
            key,
            destination
        },
        redirectTo: redirect_to
    }
};


export default {
    fetch_content,
    refresh_content,
    push_form
}
