import {ActionType} from 'constants/content'
import {find_component} from 'utils/find_component'
import {assignment_uuid} from 'utils/assignment_uuid'
import _ from 'lodash'

const initialState = Immutable.Map({
    components  : [],
    title       : '',
    breadcrumbs : [],
    page_loading: false
});

export default function content(state = initialState, action) {
    switch (action.type) {

    /**
     * FETCH CONTENT
     *
     * @set components:array
     */
        case ActionType.FETCH_CONTENT:
            return state;

        case ActionType.FETCH_CONTENT_COMPLETED:
            const DATA = action.data[0];

            // TODO delimiter breadcrumbs and components
            return state
                .set('components', assignment_uuid(DATA.content || []))
                .set('breadcrumbs', DATA.breadcrumbs || []);

        case ActionType.FETCH_CONTENT_FAILED:
            return state;


    /**
     * PAGE LOADING
     *
     * @set page_loading:boolean
     */
        case ActionType.PAGE_LOADING:
            return state.set('page_loading', true);

        case ActionType.PAGE_LOADING_COMPLETED:
            return state.set('page_loading', false);

        case ActionType.PAGE_LOADING_FAILED:
            return state.set('page_loading', false);



    /**
     * UPDATE CONTENT IN COMPONENT
     *
     * @set components:array
     */
        case ActionType.REFRESH_CONTENT:
            return state;

        case ActionType.REFRESH_CONTENT_COMPLETED:
            return state.set('components', find_component(Immutable.fromJS(state.get('components')), component => {
                return component.get('uuid') === action.params.id
            }, component => {
                return component.set('child_components', assignment_uuid(action.data))
            }).toJS());

        case ActionType.REFRESH_CONTENT_FAILED:
            return state;


    /**
     * Fetch data from api, when calling form data
     *
     * @set components
     */
        case ActionType.PUSH_FORM:
            return state;

        case ActionType.PUSH_FORM_COMPLETED:
            return state.set('components', find_component(Immutable.fromJS(state.get('components')), component => {
                return component.get('id') === action.params.destination
            }, component => {
                return component.set('child_components', assignment_uuid(action.data))
            }).toJS());

        case ActionType.PUSH_FORM_FAILED:
            return state;

        default:
            return state;
    }
}




